# React Dynamic Form v2

`react-dynamic-form-v2` is a React library for dynamically generating forms using JSON configurations. It leverages Material-UI (MUI) components and Formik for form handling and validation.

## Features

- **Dynamic Form Generation:** Create forms on the fly using a JSON configuration.
- **Material-UI Integration:** Utilizes MUI components for a consistent and modern UI.
- **Formik Integration:** Built-in form handling, validation, and error management.
- **Custom Validation:** Supports custom validation rules using Yup.

## Installation

You can install the library via npm:

```bash
npm install react-dynamic-form-v2

# Usage

Here's a basic example of how to use the react-dynamic-form-v2 library:

<pre><code> ```jsx import React from 'react'; import DynamicForm from 'react-dynamic-form-v2'; const formJson = { form_data: [ { key: "legal_name", type: "input", props: { placeholder: "Enter name", pattern: "^[a-z A-Z 0-9\\s]{1,50}$", type: "text", required: true, label: "Name", minLength: 1, maxLength: 50, }, }, { key: "keywords", type: "input", props: { placeholder: "Enter keyword", pattern: "^[a-z A-Z 0-9]{1,10}$", type: "text", label: "Keyword", minLength: 0, maxLength: 10, }, }, { key: "parent_organisation", type: "select", defaultValue: "company", props: { required: true, label: "Parent Department", options: [ { value: "id", label: "company", }, ], }, }, // Add more fields as needed ], }; const App = () => { const handleFormSubmit = (formData) => { console.log("Form data submitted:", formData); }; return ( <div> <h1>Dynamic Form Example</h1> <DynamicForm formJson={formJson} onSubmit={handleFormSubmit} /> </div> ); }; export default App; ``` </code></pre>

## JSON Schema

The `formJson` object structure is as follows:

- **`form_data`**: An array of form fields.

Each field object in the `form_data` array should contain:

- **`key`**: A unique identifier for the form field.
- **`type`**: The type of input (e.g., `input`, `select`, `tel`).
- **`props`**: An object containing the properties for the form field, including:
  - **`label`**: The label for the field.
  - **`placeholder`**: The placeholder text.
  - **`type`**: The input type (e.g., `text`, `tel`).
  - **`required`**: A boolean indicating whether the field is required.
  - **`minLength`**: The minimum length for input.
  - **`maxLength`**: The maximum length for input.
  - **`pattern`**: A regex pattern for validation.
  - **`options`**: (For select fields) An array of option objects, each with:
    - **`value`**: The option value.
    - **`label`**: The option label.

## Customization

You can customize the form by:

- Modifying the `formJson` configuration.
- Adding custom validation rules.
- Styling the components using MUI's styling system.

